<?php
/*
Plugin Name: WP-RecentCategoryPosts
Plugin URI: http://www.delphiarea.com/products/wordpress-plugins/wp-recentcategoryposts/
Description: Adds a sidebar widget to show the most recent posts in a specific category.
Version: 1.1
Author: Kambiz R. Khojasteh
Author URI: kambiz@delphiarea.com
Tags: widget, category, posts
*/

add_action('plugins_loaded', 'widget_recent_category_posts_init');

function widget_recent_category_posts_init() {
	if (function_exists('register_sidebar_widget')) {
		load_plugin_textdomain('wp-recentcategorywidget', false, 'wp-recentcategorywidget');
		$options = get_option('widget_recent_category_posts');
		if (!is_array($options))
			$options = array();
		$widget_ops = array('classname' => 'widget_recent_category_posts', 'description' => __('The most recent posts on a specific category', 'wp-recentcategorywidget'));
		$control_ops = array('id_base' => 'catposts');
		$name = __('Category Recent Posts', 'wp-recentcategorywidget');
		$id = false;
		foreach (array_keys($options) as $o) {
			if (!isset($options[$o]['title']))
				continue;
			$id = "catposts-$o";
			wp_register_sidebar_widget($id, $name, 'widget_recent_category_posts', $widget_ops, array('number' => $o));
			wp_register_widget_control($id, $name, 'widget_recent_category_posts_control', $control_ops, array('number' => $o));
		}
		if (!$id) {
			wp_register_sidebar_widget('catposts-1', $name, 'widget_recent_category_posts', $widget_ops, array('number' => 1));
			wp_register_widget_control('catposts-1', $name, 'widget_recent_category_posts_control', $control_ops, array('number' => 1));
		}
	}
}

function widget_recent_category_posts_defaults($options = null) {
	$defaults = array (
	  'title'				=> '',
	  'category'		=> 1,
	  'limit'				=> 5,
    'show_date'   => 0,
	  'show_link'		=> 1,
	  'link_title'	=> __('More &raquo;', 'wp-recentcategorywidget')
	);
	return array_merge($defaults, (array) $options);
}

function widget_recent_category_posts($args, $widget_args = 1) {
	global $id, $post, $previousday;
	extract($args, EXTR_SKIP);
	if (is_numeric($widget_args))
		$widget_args = array('number' => $widget_args);
	$widget_args = wp_parse_args($widget_args, array('number' => -1));
	extract($widget_args, EXTR_SKIP);
	
	$options = get_option('widget_recent_category_posts');
	if (!isset($options[$number]))
		return;
	$options[$number] = widget_recent_category_posts_defaults($options[$number]);
	extract($options[$number], EXTR_SKIP);
	
	if (empty($title))
		$title = get_cat_name($category);
	$title = apply_filters('widget_title', $title);

	$posts = get_posts(array('category' => $category, 'numberposts' => $limit, 'exclude' => is_single() ? $id : '', 'post_type' => 'post'));
	
	if ($posts) {
		echo $before_widget;
		echo $before_title . $title . $after_title;
		echo "<ul class=\"category-posts-$category\">";
    $save_post = $post;
		foreach($posts as $post) {
			$permalink = get_permalink($post->ID);
			$title = get_the_title($post->ID);
			echo '<li>';
      echo "<a href=\"$permalink\">$title</a>";
      if ($show_date) {
        $previousday = '';
        the_date('', '<br /><small>', '</small>');
      }
      echo '</li>';
		}
    $post = $save_post;
		echo "</ul>";
		if ($show_link) {
			$link = get_category_link($category);
			echo "<a href=\"$link\">$link_title</a>";
		}
		echo $after_widget;
	}
}
  
function widget_recent_category_posts_control($widget_args) {
	global $wp_registered_widgets;
	static $updated = false;
	
	if (is_numeric($widget_args))
		$widget_args = array('number' => $widget_args);
	$widget_args = wp_parse_args($widget_args, array('number' => -1));
	extract($widget_args, EXTR_SKIP);
	$options = get_option('widget_recent_category_posts');
	if (!is_array($options))
		$options = array();
		
	if (!$updated && !empty($_POST['sidebar'])) {
		$sidebar = (string) $_POST['sidebar'];
		$sidebars_widgets = wp_get_sidebars_widgets();
		if (isset($sidebars_widgets[$sidebar]))
			$this_sidebar =& $sidebars_widgets[$sidebar];
		else
			$this_sidebar = array();
		foreach ($this_sidebar as $_widget_id) {
			if ('widget_recent_category_posts' == $wp_registered_widgets[$_widget_id]['callback'] && isset($wp_registered_widgets[$_widget_id]['params'][0]['number'])) {
				$widget_number = $wp_registered_widgets[$_widget_id]['params'][0]['number'];
				if (!in_array("catposts-$widget_number", $_POST['widget-id'])) // the widget has been removed.
					unset($options[$widget_number]);
			}
		}
		foreach ((array) $_POST['widget_catposts'] as $widget_number => $widget_catposts) {
			if (!isset($widget_catposts['title']) && isset($options[$widget_number])) // user clicked cancel
				continue;
			$options[$widget_number]['title'] = strip_tags(stripslashes($widget_catposts['title']));
			$options[$widget_number]['category'] = intval($widget_catposts['category']);
			$options[$widget_number]['limit'] = intval($widget_catposts['limit']);
      $options[$widget_number]['show_date'] = intval($widget_catposts['show-date']);
      $options[$widget_number]['show_link'] = intval($widget_catposts['show-link']);
			$options[$widget_number]['link_title'] = stripslashes($widget_catposts['link-title']);
		}
		update_option('widget_recent_category_posts', $options);
		$updated = true;
	}

	if (-1 == $number) {
		$number = '%i%';
		$this_options = array();
	}
	else
		$this_options = $options[$number];
	$this_options = widget_recent_category_posts_defaults($this_options);
		
  $title = attribute_escape($this_options['title']);
	$category = intval($this_options['category']);
	$limit = intval($this_options['limit']);
  $show_date = intval($this_options['show_date']);
  $show_link = intval($this_options['show_link']);
  $link_title = htmlentities($this_options['link_title'], ENT_QUOTES, get_bloginfo('charset'));
  
?>
	<input type="hidden" id="widget_catposts[<?php echo $number; ?>][submit]" name="widget_catposts[<?php echo $number; ?>][submit]" value="1" />
	<p>
		<label for="widget_catposts[<?php echo $number; ?>][title]">
			<?php _e('Title:', 'wp-recentcategorywidget'); ?>
			<input class="widefat" id="widget_catposts[<?php echo $number; ?>][title]" name="widget_catposts[<?php echo $number; ?>][title]" type="text" value="<?php echo $title; ?>" />
		</label>
	</p>
  <hr />
	<p>
		<label for="widget_catposts[<?php echo $number; ?>][category]">
			<?php _e('Category:', 'wp-recentcategorywidget'); ?>
			<?php wp_dropdown_categories("selected=$category&class=widefat&name=widget_catposts[$number][category]&hierarchical=1&hide_empty=0&orderby=name"); ?>
		</label>
	</p>
	<p>
		<label for="widget_catposts[<?php echo $number; ?>][limit]">
			<?php _e('Number of posts to show:', 'wp-recentcategorywidget'); ?>
			<input class="widefat" id="widget_catposts[<?php echo $number; ?>][limit]" name="widget_catposts[<?php echo $number; ?>][limit]" type="text" value="<?php echo $limit; ?>" />
		</label>
	</p>
  <p>
    <label for="widget_catposts[<?php echo $number; ?>][show-date]">
      <input id="widget_catposts[<?php echo $number; ?>][show-date]" name="widget_catposts[<?php echo $number; ?>][show-date]" type="checkbox" value="1" <?php echo $show_date ? 'checked="checked"' : ''; ?> />
      <?php _e('Display date of posts', 'wp-recentcategorywidget'); ?>
    </label>
  </p>
  <hr />
	<p>
		<label for="widget_catposts[<?php echo $number; ?>][show-link]">
			<input id="widget_catposts[<?php echo $number; ?>][show-link]" name="widget_catposts[<?php echo $number; ?>][show-link]" type="checkbox" value="1" <?php echo $show_link ? 'checked="checked"' : ''; ?> />
			<?php _e('Show link to the archive', 'wp-recentcategorywidget'); ?>
		</label>
	</p>
	<p>
		<label for="widget_catposts[<?php echo $number; ?>][link-title]">
			<?php _e('Title of link to the archive:', 'wp-recentcategorywidget'); ?>
			<input class="widefat" id="widget_catposts[<?php echo $number; ?>][link-title]" name="widget_catposts[<?php echo $number; ?>][link-title]" type="text" value="<?php echo $link_title; ?>" />
			<br /><small style="color: #777;"><?php _e('HTML is allowed.', 'wp-recentcategorywidget'); ?></small>
		</label>
	</p>
<?php
}
  
?>